==> onegov.org-0.26.0.tar.gz: onegov.org-0.26.0/onegov/org/forms/__init__.py <==
from onegov.org.forms.allocation import DaypassAllocationEditForm
from onegov.org.forms.allocation import DaypassAllocationForm
from onegov.org.forms.allocation import RoomAllocationEditForm
from onegov.org.forms.allocation import RoomAllocationForm
from onegov.org.forms.directory import DirectoryForm
from onegov.org.forms.directory import DirectoryImportForm
from onegov.org.forms.event import EventForm
from onegov.org.forms.form_definition import FormDefinitionForm
from onegov.org.forms.form_export import FormSubmissionsExport
from onegov.org.forms.form_registration import FormRegistrationWindowForm
from onegov.org.forms.generic import ExportForm, DateRangeForm
from onegov.org.forms.imageset import ImageSetForm
from onegov.org.forms.newsletter import NewsletterForm, NewsletterSendForm
from onegov.org.forms.page import LinkForm, PageForm
from onegov.org.forms.person import PersonForm
from onegov.org.forms.reservation import ReservationForm
from onegov.org.forms.resource import ResourceCleanupForm
from onegov.org.forms.resource import ResourceExportForm
from onegov.org.forms.resource import ResourceForm
from onegov.org.forms.resource_recipient import ResourceRecipientForm
from onegov.org.forms.settings import SettingsForm
from onegov.org.forms.signup import SignupForm
from onegov.org.forms.ticket_note import TicketNoteForm
from onegov.org.forms.user import ManageUserForm, NewUserForm
from onegov.org.forms.userprofile import UserProfileForm


__all__ = [
    'DateRangeForm',
    'DaypassAllocationEditForm',
    'DaypassAllocationForm',
    'DirectoryForm',
    'DirectoryImportForm',
    'EventForm',
    'ExportForm',
    'FormDefinitionForm',
    'FormRegistrationWindowForm',
    'FormSubmissionsExport',
    'ImageSetForm',
    'LinkForm',
    'ManageUserForm',
    'NewsletterForm',
    'NewsletterSendForm',
    'NewUserForm',
    'PageForm',
    'PersonForm',
    'ReservationForm',
    'ResourceCleanupForm',
    'ResourceExportForm',
    'ResourceForm',
    'ResourceRecipientForm',
    'RoomAllocationEditForm',
    'RoomAllocationForm',
    'SettingsForm',
    'SignupForm',
    'TicketNoteForm',
    'UserProfileForm',
]

==> onegov.org-0.47.0.tar.gz: onegov.org-0.47.0/onegov/org/forms/__init__.py <==
from onegov.org.forms.allocation import DaypassAllocationEditForm
from onegov.org.forms.allocation import DaypassAllocationForm
from onegov.org.forms.allocation import RoomAllocationEditForm
from onegov.org.forms.allocation import RoomAllocationForm
from onegov.org.forms.directory import DirectoryForm
from onegov.org.forms.directory import DirectoryImportForm
from onegov.org.forms.event import EventForm
from onegov.org.forms.form_definition import FormDefinitionForm
from onegov.org.forms.form_export import FormSubmissionsExport
from onegov.org.forms.form_registration import FormRegistrationWindowForm
from onegov.org.forms.generic import ExportForm, DateRangeForm
from onegov.org.forms.imageset import ImageSetForm
from onegov.org.forms.newsletter import NewsletterForm
from onegov.org.forms.newsletter import NewsletterSendForm
from onegov.org.forms.newsletter import NewsletterTestForm
from onegov.org.forms.page import LinkForm, PageForm
from onegov.org.forms.person import PersonForm
from onegov.org.forms.reservation import ReservationForm
from onegov.org.forms.resource import ResourceCleanupForm
from onegov.org.forms.resource import ResourceExportForm
from onegov.org.forms.resource import ResourceForm
from onegov.org.forms.resource_recipient import ResourceRecipientForm
from onegov.org.forms.settings import AnalyticsSettingsForm
from onegov.org.forms.settings import FooterSettingsForm
from onegov.org.forms.settings import GeneralSettingsForm
from onegov.org.forms.settings import HomepageSettingsForm
from onegov.org.forms.settings import MapSettingsForm
from onegov.org.forms.settings import ModuleSettingsForm
from onegov.org.forms.signup import SignupForm
from onegov.org.forms.ticket_note import TicketNoteForm
from onegov.org.forms.user import ManageUserForm, NewUserForm
from onegov.org.forms.userprofile import UserProfileForm


__all__ = [
    'AnalyticsSettingsForm',
    'DateRangeForm',
    'DaypassAllocationEditForm',
    'DaypassAllocationForm',
    'DirectoryForm',
    'DirectoryImportForm',
    'EventForm',
    'ExportForm',
    'FooterSettingsForm',
    'FormDefinitionForm',
    'FormRegistrationWindowForm',
    'FormSubmissionsExport',
    'GeneralSettingsForm',
    'HomepageSettingsForm',
    'ImageSetForm',
    'LinkForm',
    'ManageUserForm',
    'MapSettingsForm',
    'ModuleSettingsForm',
    'NewsletterForm',
    'NewsletterSendForm',
    'NewsletterTestForm',
    'NewUserForm',
    'PageForm',
    'PersonForm',
    'ReservationForm',
    'ResourceCleanupForm',
    'ResourceExportForm',
    'ResourceForm',
    'ResourceRecipientForm',
    'RoomAllocationEditForm',
    'RoomAllocationForm',
    'SignupForm',
    'TicketNoteForm',
    'UserProfileForm',
]
